@@ -4,7 +4,7 @@ library("multcomp")
 set.seed(290875)
 
 data("warpbreaks")
-fm1 <- aov(breaks ~ wool * tension, data = warpbreaks)
+fm1 <- aov(breaks ~ wool + tension, data = warpbreaks)
 
 TukeyHSD(fm1, "tension", ordered = FALSE)
 confint(glht(fm1, linfct = mcp(tension = "Tukey")))
