@@ -5,7 +5,6 @@
 
 library("multcomp")
 
-nlmeOK <- require("nlme")
 lme4OK <- require("lme4")
 if (lme4OK) {
 
@@ -17,8 +16,11 @@ if (lme4OK) {
     glme4 <- glht(stool.lmer, K)
     glme41 <- glht(stool.lmer, mcp(Type = "Tukey"))
     stopifnot(all.equal(coef(glme4), coef(glme41)))
+    print(summary(glme41, test = Chisqtest()))
 
+    nlmeOK <- require("nlme")
     if (nlmeOK) {
+
         stool.lme <- lme(effort ~ Type, data = ergoStool,
                         random = ~ 1 | Subject)
         gnlme <- glht(stool.lme,K)
@@ -28,20 +30,3 @@ if (lme4OK) {
         stopifnot(all.equal(coef(glme4), coef(gnlme2)))
     }
 }
-
-### and now for lmer2 as well
-if (lme4OK) {
-
-    data("ergoStool", package = "nlme")
-
-    stool.lmer <- lmer2(effort ~ Type + (1 | Subject),
-                        data = ergoStool)
-    glme4 <- glht(stool.lmer, K)
-    glme41 <- glht(stool.lmer, mcp(Type = "Tukey"))
-    stopifnot(all.equal(coef(glme4), coef(glme41)))
-
-    if (nlmeOK) {
-        stopifnot(all.equal(coef(glme4), coef(gnlme)))
-    }
-}
-
